django-twilio
=============

django-twilio is a simple library for building twilio-powered `Django
<https://www.djangoproject.com/>`_ webapps.

`Twilio <http://www.twilio.com/>`_ is a powerful HTTP API that allows you to
build powerful voice & SMS apps. The goal of this library is to help make
building telephony applications as simple as humanly possible with twilio.


User's Guide
------------

This part of the documentation contains an extensive walk through of
django-twilio. It begins with some background information about django-twilio,
then focuses on step-by-step integration of django-twilio into your existing
Django web applications.

.. toctree::
    :maxdepth: 2

    foreword
    install
    decorators
    views
    rest
    gotchas
    howto
    contribute

API Reference
-------------

This section of the documentation provides detailed information on all of
django-twilio's public facing APIs.

.. toctree::
    :maxdepth: 2

    admin_module
    client_module
    decorators_module
    models_module
    views_module

Indices and Tables
------------------

The following is auto-generated documentation that can be used to quickly find
relevant parts of this documentation.

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
